@@ -169,11 +169,14 @@ class DataContext():
                         time.sleep(0.001)
                         elapsed_time = time.perf_counter() - reference_time
                         to_sleep = desired_time - elapsed_time
-                # Инициализация - для GPIB важно отослать все команды до того как начал считывание, так как считывание блокирует интерфейс
+                # Capture the actual output value
                 future = executor.submit(wr.update)
+                # Trigger all the devices to start measuring
                 if init_readables:
-                    concurrent.futures.wait([executor.submit(rd.init_update) for rd in init_readables])
-                # Собственно считывание
+                    concurrent.futures.wait(
+                        [executor.submit(rd.init_update) for rd in init_readables]
+                        )
+                # Finish reading the devices
                 futures = [executor.submit(rd.update) for rd in self._readables]
                 futures.append(future)
                 concurrent.futures.wait(futures)
