@@ -231,6 +231,8 @@ class ReadableControl(DeviceControl):
         self.curr_value = self._values[-1]
 
     def num_channels(self):
+        if callable(self._channels_num):
+            return self._channels_num()
         return self._channels_num
 
     def data(self, channel=0):
