@@ -29,9 +29,7 @@ from threading import RLock
 from abc import (
     ABCMeta, abstractmethod, abstractstaticmethod, abstractproperty
 )
-# TODO: remove this connection
-from pyxperiment.frames.device_config import DeviceConfig
-from .device_options import (
+from pyxperiment.controller.device_options import (
     TimeoutControl, ValueDeviceOption, DeviceOption, ActionControl
 )
 
@@ -93,12 +91,12 @@ class Instrument(metaclass=ABCMeta):
 
     def to_remote(self):
         """
-        Make preparations as a sweep is starting
+        Make preparations as an experiment is starting
         """
 
     def to_local(self):
         """
-        Enable local controls after sweep is over
+        Enable local controls after experiment is over
         """
 
     def is_sweep_based(self):
@@ -122,7 +120,7 @@ class Instrument(metaclass=ABCMeta):
     @classmethod
     def get_properties(cls):
         """
-        Return all the sweepable options for this instrument
+        Return all the scannable options for this instrument
         """
         properties = [
             prop
@@ -185,6 +183,3 @@ class Instrument(metaclass=ABCMeta):
         ret.insert(0, ('Address', self.location))
         ret.insert(0, ('Name', self.device_name()))
         return ret
-
-    def get_config_class(self):
-        return DeviceConfig
