@@ -77,14 +77,18 @@ class TextDataWriter():
                     print(*['NaN' for data_line in data], file=text_file)
 
     def print_device_info(self, info, file):
-        """Saves sweep info for single device"""
+        """
+        Saves experiment info for a single device
+        """
         device_name = next(filter(lambda x: x[0] == 'Name', info))
         print('Device: ' + device_name[1], end='\n', file=file)
         for field in filter(lambda x: x[0] != 'Name', info):
             print('\t' + field[0] + ': ' + field[1], end='\n', file=file)
 
     def save_info_file(self, yinfo, xinfo, sweep_info):
-        """Saves sweep info into separate file"""
+        """
+        Saves experiment info file
+        """
         file_name = self.get_filename().replace('.dat', '.info')
         with open(file_name, "w") as text_file:
             print('Y devices: ', end='\n', file=text_file)
