@@ -28,7 +28,7 @@ from decimal import Decimal
 
 from pyxperiment.controller import VisaInstrument
 from pyxperiment.controller.device_options import (
-    ValueDeviceOption, BooleanOption, ListDeviceOption, TimeoutControl
+    ListControl, ValueDeviceOption, BooleanControl, TimeoutControl
 )
 
 class Agilent34xxxDMM(VisaInstrument):
@@ -80,19 +80,10 @@ class Agilent34xxxDMM(VisaInstrument):
     def channels_num(self):
         return int(self.sample_count.get_value())
 
-    def set_function(self, unit):
-        if unit == 'volt':
-            self.write('func:volt:dc')
-        elif unit == 'curr':
-            self.write('func:curr:dc')
-        else:
-            raise ValueError('Invalid unit')
-
-    def get_function(self):
-        return self.query('func?')
-
-    function = ListDeviceOption(
-        'Function', ['volt', 'curr'], get_function, set_function
+    function = ListControl(
+        'Function', dict(zip(['Voltage', 'Current'], ['volt', 'curr'])),
+        get_func=lambda instr: instr.query('func?'),
+        set_func=lambda instr, val: instr.write('func:' + val + ':dc')
     )
 
     def set_autorange(self, value):
@@ -101,7 +92,7 @@ class Agilent34xxxDMM(VisaInstrument):
     def get_autorange(self):
         return self.query('volt:dc:rang:auto?')
 
-    autorange = BooleanOption(
+    autorange = BooleanControl(
         'Auto Range',
         get_autorange,
         set_autorange
@@ -124,7 +115,7 @@ class Agilent34xxxDMM(VisaInstrument):
                 return range_value
         raise ValueError('Unkwown range ' + value)
 
-    measurement_range = ListDeviceOption(
+    measurement_range = ListControl(
         'Range, V',
         range_values,
         get_func=_get_range,
@@ -149,7 +140,7 @@ class Agilent34xxxDMM(VisaInstrument):
                 return nplc_value
         raise ValueError('Unkwown NPLC: ' + value)
 
-    nplc = ListDeviceOption(
+    nplc = ListControl(
         'Power cycles',
         nplc_values,
         _get_nplc,
@@ -189,7 +180,7 @@ class Agilent34xxxDMM(VisaInstrument):
         cmd = 'sens:volt:dc:zero:auto?' if self.model != '34401A' else 'zero:auto?'
         return self.query(cmd)
 
-    autozero = BooleanOption(
+    autozero = BooleanControl(
         'Auto Zero',
         _get_autozero,
         _set_autozero
@@ -205,7 +196,7 @@ class Agilent34xxxDMM(VisaInstrument):
             return 0
         return self.query('volt:aper:enab?')
 
-    aperture_on = BooleanOption(
+    aperture_on = BooleanControl(
         'Aperture on',
         get_func=_get_apertureon,
         set_func=lambda instr, value: instr.write('volt:aper:enab ' + value),
@@ -227,7 +218,7 @@ class Agilent34xxxDMM(VisaInstrument):
     def _get_highz(self):
         return self.query('volt:dc:imp:auto?' if self.model != '34401A' else 'inp:imp:auto?')
 
-    highz = BooleanOption(
+    highz = BooleanControl(
         'Auto Impedance',
         get_func=_get_highz,
         set_func=_set_highz
@@ -251,7 +242,7 @@ class Agilent34xxxDMM(VisaInstrument):
         sweepable=False
     )
 
-    trigger_delay_auto = BooleanOption(
+    trigger_delay_auto = BooleanControl(
         'Auto trigger delay',
         get_func=lambda instr: instr.query('TRIG:DEL:AUTO?'),
         set_func=lambda instr, value: instr.write('TRIG:DEL:AUTO ' + value),
@@ -272,7 +263,7 @@ class Agilent34xxxDMM(VisaInstrument):
                 self.model == Agilent34xxxDMM.MODEL_34465A or
                 self.model == Agilent34xxxDMM.MODEL_34470A)
 
-    display_state = BooleanOption(
+    display_state = BooleanControl(
         'Display on',
         get_func=_get_display_state,
         set_func=_set_display_state,
