@@ -28,7 +28,7 @@ from decimal import Decimal
 
 from pyxperiment.controller import VisaInstrument
 from pyxperiment.controller.device_options import (
-    ListDeviceOption, BooleanOption, ValueDeviceOption, TimeoutControl
+    ListControl, BooleanControl, ValueDeviceOption, TimeoutControl
 )
 
 class AgilentB29x1xSMU(VisaInstrument):
@@ -44,7 +44,7 @@ class AgilentB29x1xSMU(VisaInstrument):
 
         self.set_options([
             self.output,
-            ListDeviceOption('Function', list(self.function_values.keys()), self.get_function, self.set_function),
+            ListControl('Function', list(self.function_values.keys()), self.get_function, self.set_function),
             ValueDeviceOption('Voltage', 'V', self.get_sour_volt, self.set_sour_volt),
             ValueDeviceOption('Current', 'A', self.get_sour_curr, self.set_sour_curr),
             self.volt_range_auto,
@@ -73,6 +73,9 @@ class AgilentB29x1xSMU(VisaInstrument):
     def device_name(self):
         return self.idn[0] + ' ' + self.idn[1] + ' SMU'
 
+    def device_id(self):
+        return self.idn[2]
+
     def get_value(self):
         func = self.get_function()
         if func == self.VOLT_NAME:
@@ -97,7 +100,7 @@ class AgilentB29x1xSMU(VisaInstrument):
     #    values = [x for x in values if abs(Decimal(x)) > current_range[1] or divmod(Decimal(x),current_range[2])[1] > 0]
     #    return len(values) == 0
 
-    output = BooleanOption(
+    output = BooleanControl(
         'Output on',
         get_func=lambda instr: instr.query(':OUTP?'),
         set_func=lambda instr, value: instr.write(':OUTP '+value),
@@ -151,7 +154,7 @@ class AgilentB29x1xSMU(VisaInstrument):
     def set_curr_limit(self, value):
         self.write(':SENS:CURR:PROT ' + str(value))
 
-    nplc_auto = BooleanOption(
+    nplc_auto = BooleanControl(
         'NPLC auto',
         get_func=lambda instr: instr.query(':SENS:VOLT:NPLC:AUTO?'),
         set_func=lambda instr, value: instr.write(':SENS:VOLT:NPLC:AUTO '+value)
@@ -165,7 +168,7 @@ class AgilentB29x1xSMU(VisaInstrument):
         sweepable=False
     )
 
-    meas_volt_range_auto = BooleanOption(
+    meas_volt_range_auto = BooleanControl(
         'Auto voltage range',
         get_func=lambda instr: instr.query(':SENS:VOLT:RANG:AUTO?'),
         set_func=lambda instr, value: instr.write(':SENS:VOLT:RANG:AUTO '+value)
@@ -186,7 +189,7 @@ class AgilentB29x1xSMU(VisaInstrument):
                 return range_value
         raise ValueError('Unkwown range ' + value)
 
-    meas_volt_range = ListDeviceOption(
+    meas_volt_range = ListControl(
         'Voltage range, V',
         meas_volt_range_values,
         get_func=_get_meas_volt_range,
@@ -204,7 +207,7 @@ class AgilentB29x1xSMU(VisaInstrument):
         get_func=lambda instr: instr.query(':MEAS:CURR?'),
     )
 
-    volt_range_auto = BooleanOption(
+    volt_range_auto = BooleanControl(
         'Source voltage range auto',
         get_func=lambda instr: instr.query(':SOUR:VOLT:RANG:AUTO?'),
         set_func=lambda instr, value: instr.write(':SOUR:VOLT:RANG:AUTO '+value),
@@ -212,7 +215,7 @@ class AgilentB29x1xSMU(VisaInstrument):
         false_str='OFF'
     )
 
-    curr_range_auto = BooleanOption(
+    curr_range_auto = BooleanControl(
         'Source current range auto',
         get_func=lambda instr: instr.query(':SOUR:CURR:RANG:AUTO?'),
         set_func=lambda instr, value: instr.write(':SOUR:CURR:RANG:AUTO '+value),
@@ -253,7 +256,7 @@ class AgilentB29x1xSMU(VisaInstrument):
                 return range_value
         raise ValueError('Unkwown range ' + value)
 
-    volt_range = ListDeviceOption(
+    volt_range = ListControl(
         'Source voltage range, V',
         volt_range_values,
         get_func=_get_volt_range,
@@ -274,7 +277,7 @@ class AgilentB29x1xSMU(VisaInstrument):
                 return range_value
         raise ValueError('Unkwown range ' + value)
 
-    curr_range = ListDeviceOption(
+    curr_range = ListControl(
         'Source current range, A',
         curr_range_values,
         get_func=_get_curr_range,
