@@ -110,7 +110,7 @@ class YokogawaGS200(VisaInstrument):
         return len(values) == 0
 
     def get_output(self):
-        return self._query_boolean('OUTP?')
+        return int(self.query('OUTP?')) != 0
 
     def set_output(self, value):
         self.write('OUTP ' + ('1' if value else '0'))
