@@ -33,15 +33,15 @@ class TextPanel(wx.Panel):
         self.parent = parent
         self.last_value = initval
         self.edit = wx.TextCtrl(
-            self, -1,
+            self, wx.ID_ANY,
             size=size,
             value=initval,
             style=style
             )
         if show_mod:
-            self.Bind(wx.EVT_TEXT, self.OnTextChange, self.edit)
+            self.Bind(wx.EVT_TEXT, self._on_text_change, self.edit)
 
-    def OnTextChange(self, event):
+    def _on_text_change(self, event):
         if self.IsModified():
             self.edit.SetForegroundColour((255, 0, 0))
         else:
@@ -141,9 +141,9 @@ class ModifiedCheckBox(wx.CheckBox):
         super().__init__(parent, wx.ID_ANY, label=label, style=wx.CHK_3STATE)
         self.Set3StateValue(wx.CHK_UNDETERMINED)
         self.last_value = wx.CHK_UNDETERMINED
-        self.Bind(wx.EVT_CHECKBOX, self.on_check_change, self)
+        self.Bind(wx.EVT_CHECKBOX, self._on_check_change, self)
 
-    def on_check_change(self, event):
+    def _on_check_change(self, event):
         del event
         if self.IsModified():
             self.SetForegroundColour((255, 0, 0))
@@ -166,4 +166,23 @@ class ModifiedCheckBox(wx.CheckBox):
             self.Enable()
         else:
             self.Disable()
-    
\ No newline at end of file
+
+class ActionButton(wx.Button):
+
+    def __init__(self, parent, label, handler):
+        super().__init__(parent, label=label)
+        self._action_handler = handler
+        self.Bind(wx.EVT_BUTTON, self._on_button, self)
+
+    def IsModified(self):
+        return False
+
+    def _on_button(self, event):
+        del event
+        self._action_handler()
+
+    def SetEnabled(self, value):
+        if value:
+            self.Enable()
+        else:
+            self.Disable()
