@@ -29,7 +29,7 @@ import time
 import wx
 
 from pyxperiment.controller.device_options import (
-    ActionControl, ListDeviceOption, BooleanDeviceOption, ValueDeviceOption, StateDeviceOption
+    ActionControl, ListControl, BooleanControl, ValueDeviceOption, StateControl
 )
 from pyxperiment.settings.view_settings import ViewSettings
 from .basic_panels import (
@@ -40,10 +40,10 @@ def option_to_control(panel, option):
     """
     This method creates a corresponding GUI element for a device control
     """
-    if isinstance(option, ListDeviceOption):
+    if isinstance(option, ListControl):
         return ControlField(CaptionDropBox(panel, option.name, option.values_list()),
                             option.get_value, option.set_value, option)
-    if isinstance(option, BooleanDeviceOption):
+    if isinstance(option, BooleanControl):
         return ControlField(ModifiedCheckBox(panel, option.name),
                             option.get_value, option.set_value, option)
     if isinstance(option, ValueDeviceOption):
@@ -55,7 +55,7 @@ def option_to_control(panel, option):
         return ControlField(panel,
                             option.get_value,
                             None if option.is_readable() else option.set_value, option)
-    if isinstance(option, StateDeviceOption):
+    if isinstance(option, StateControl):
         return ControlField(CaptionTextPanel(panel, option.name),
                             option.get_value, None, option)
     if isinstance(option, ActionControl):
