@@ -25,6 +25,7 @@
     THE SOFTWARE.
 """
 
+from pyxperiment.core.application import PyXperimentApp
 import wx
 import pyvisa
 
@@ -134,9 +135,7 @@ class DeviceSelectPanel(wx.Panel):
             return
         if device == DeviceSelectPanel.NONE_DEVICE:
             return
-        config = device.get_config_class()
-        config_frame = config(self.Parent, device)
-        config_frame.Show()
+        PyXperimentApp().show_conf_wnd(device)
 
     def get_device(self, no_param=False):
         value = self.dropbox_device.GetSelection()
