@@ -107,6 +107,16 @@ class SweepPanel(wx.Panel):
         device_property.sweep.delay = delay
         device_property.sweep.returnDelay = return_delay
 
+    def validate(self):
+        # TODO: move to experiment
+        if callable(getattr(self.device, 'check_values', None)) and not self.device.check_values(self.GetRange()):
+            dlg = wx.MessageDialog(
+                None, 'The values range contains points, which are unable to be set by selected device.',
+                'Wrong dataset', wx.OK | wx.ICON_INFORMATION)
+            dlg.ShowModal()
+            return False
+        return True
+
 class TimeSweepPanel(SweepPanel):
     """
     A special class for time sweep panel
@@ -267,3 +277,13 @@ class DeviceSweepPanel(SweepPanel):
 
     def GetRange(self):
         return str(self.edit_range.edit.Value)
+
+    def validate(self):
+        # TODO: move to experiment
+        if callable(getattr(self.device, 'check_values', None)) and not self.device.check_values(self.range):
+            dlg = wx.MessageDialog(
+                None, 'The values range contains points, which are unable to be set by selected device.',
+                'Wrong dataset', wx.OK | wx.ICON_INFORMATION)
+            dlg.ShowModal()
+            return False
+        return True
