@@ -215,15 +215,6 @@ class RangeSelectFrame(wx.Frame):
             return False
         return True
 
-    def validate_device_panel(self, panel):
-        if callable(getattr(panel.device, 'check_values', None)) and not panel.device.check_values(panel.GetRange()):
-            dlg = wx.MessageDialog(
-                self, 'The values range contains points, which are unable to be set by selected device.',
-                'Wrong dataset', wx.OK | wx.ICON_INFORMATION)
-            dlg.ShowModal()
-            return False
-        return True
-
     def sequential_task(self, experiments):
         for i in range(int(self.edit_iterations.GetValue())):
             for experiment in experiments:
@@ -311,7 +302,7 @@ class RangeSelectFrame(wx.Frame):
                 return
 
         for panel in self.device_panels:
-            if not self.validate_device_panel(panel):
+            if not panel.validate():
                 return
 
         self.save_settings()
